@@ -77,6 +77,7 @@ TEMPLATE_NAMES_EASYBLOCK_RUN_STEP = [
 # software names for which to define <pref>ver and <pref>shortver templates
 TEMPLATE_SOFTWARE_VERSIONS = [
     # software name, prefix for *ver and *shortver
+    ('CUDA', 'cuda'),
     ('Java', 'java'),
     ('Perl', 'perl'),
     ('Python', 'py'),
@@ -145,7 +146,7 @@ for ext in extensions:
 # versionmajor, versionminor, versionmajorminor (eg '.'.join(version.split('.')[:2])) )
 
 
-def template_constant_dict(config, ignore=None, skip_lower=None):
+def template_constant_dict(config, ignore=None, skip_lower=None, toolchain=None):
     """Create a dict for templating the values in the easyconfigs.
         - config is a dict with the structure of EasyConfig._config
     """
@@ -222,12 +223,24 @@ def template_constant_dict(config, ignore=None, skip_lower=None):
         for dep in deps:
             if isinstance(dep, dict):
                 dep_name, dep_version = dep['name'], dep['version']
+
+                # take into account dependencies marked as external modules,
+                # where name/version may have to be harvested from metadata available for that external module
+                if dep.get('external_module', False):
+                    metadata = dep.get('external_module_metadata', {})
+                    if dep_name is None:
+                        # name is a list in metadata, just take first value (if any)
+                        dep_name = metadata.get('name', [None])[0]
+                    if dep_version is None:
+                        # version is a list in metadata, just take first value (if any)
+                        dep_version = metadata.get('version', [None])[0]
+
             elif isinstance(dep, (list, tuple)):
                 dep_name, dep_version = dep[0], dep[1]
             else:
                 raise EasyBuildError("Unexpected type for dependency: %s", dep)
 
-            if isinstance(dep_name, string_type) and dep_name.lower() == name.lower():
+            if isinstance(dep_name, string_type) and dep_name.lower() == name.lower() and dep_version:
                 dep_version = pick_dep_version(dep_version)
                 template_values['%sver' % pref] = dep_version
                 dep_version_parts = dep_version.split('.')
@@ -257,6 +270,17 @@ def template_constant_dict(config, ignore=None, skip_lower=None):
         except Exception:
             _log.warning("Failed to get .lower() for name %s value %s (type %s)", name, value, type(value))
 
+    # step 5. add additional conditional templates
+    if toolchain is not None and hasattr(toolchain, 'mpi_cmd_prefix'):
+        try:
+            # get prefix for commands to be run with mpi runtime using default number of ranks
+            mpi_cmd_prefix = toolchain.mpi_cmd_prefix()
+            if mpi_cmd_prefix is not None:
+                template_values['mpi_cmd_prefix'] = mpi_cmd_prefix
+        except EasyBuildError as err:
+            # don't fail just because we couldn't resolve this template
+            _log.warning("Failed to create mpi_cmd_prefix template, error was:\n%s", err)
+
     return template_values
 
 
