@@ -1,5 +1,5 @@
 ##
-# Copyright 2012-2019 Ghent University
+# Copyright 2012-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -28,6 +28,7 @@ EasyBuild support for gompi compiler toolchain (includes GCC and OpenMPI).
 :author: Kenneth Hoste (Ghent University)
 """
 from distutils.version import LooseVersion
+import re
 
 from easybuild.toolchains.gcc import GccToolchain
 from easybuild.toolchains.mpi.openmpi import OpenMPI
@@ -40,10 +41,23 @@ class Gompi(GccToolchain, OpenMPI):
 
     def is_deprecated(self):
         """Return whether or not this toolchain is deprecated."""
-        # deprecate oldest gompi toolchains (versions 1.x)
-        if LooseVersion(self.version) < LooseVersion('2000'):
-            deprecated = True
-        else:
-            deprecated = False
+        # need to transform a version like '2016a' with something that is safe to compare with '2000'
+        # comparing subversions that include letters causes TypeErrors in Python 3
+        # 'a' is assumed to be equivalent with '.01' (January), and 'b' with '.07' (June) (good enough for this purpose)
+        version = self.version.replace('a', '.01').replace('b', '.07')
+
+        deprecated = False
+
+        # make sure a non-symbolic version (e.g., 'system') is used before making comparisons using LooseVersion
+        if re.match('^[0-9]', version):
+            gompi_ver = LooseVersion(version)
+            # deprecate oldest gompi toolchains (versions 1.x)
+            if gompi_ver < LooseVersion('2000'):
+                deprecated = True
+            # gompi toolchains older than gompi/2016a are deprecated
+            # take into account that gompi/2016.x is always < gompi/2016a according to LooseVersion;
+            # gompi/2016.01 & co are not deprecated yet...
+            elif gompi_ver < LooseVersion('2016.01'):
+                deprecated = True
 
         return deprecated
